==> centreon-web-24.04.22.tar.gz: centreon-web-24.04.22/www/front_src/src/PollerWizard/translatedLabels.ts <==
export const labelExportGenerationTimeout = 'Export generation timeout';
export const labelAdvancedServerConfiguration =
  'Add advanced server configuration';

export const labelCreatePoller = 'Create new Poller';
export const labelSelectPoller = 'Select a Poller';
export const labelSelectPollerIp = 'Select Pending Poller IP';
export const labelCheckCertificate = 'Do not check SSL certificate validation';

export const labelCreatingExportTask = 'Creating Export Task';
export const labelGeneratingExportFiles = 'Generating Export Files';
export const labelAddACentreonPoller = 'Add a Centreon Poller';
export const labelAddACentreonRemoteServer = 'Add a Centreon Remote Server';
export const labelServerConfiguration = 'Server Configuration';
export const labelChoseServerType = 'Choose a server type';
export const labelCreateRemoteServer = 'Create new Remote Server';
export const labelSelectRemoteServer = 'Select a Remote Server';
export const labelSelectRemoteLinks = 'Select Pending Remote Links';
export const labelServerName = 'Server Name';
export const labelServerIp = 'Server IP address';

export const labelDbUser = 'Database username';
export const labelDbPassword = 'Database password';

export const labelCentreonCentralIp =
  'Centreon Central IP address, as seen by this server';
export const labelCentreonFolder = 'Centreon Web Folder on Remote';

export const labelLinkedRemoteMaster =
  'Attach poller to a master remote server';

export const labelLinkedadditionalRemote =
  'Attach poller to additional remote servers';

export const labelRemoteServers =
  'Select pollers to be attached to this new Remote Server';

export const labelOpenBrokerFlow =
  'Advanced: reverse Centreon Broker communication flow';

export const labelDoNotUseConfiguredProxy =
  'Do not use configured proxy to connect to this server';

export const labelFinalStep = 'Finalizing Setup';
export const labelNext = 'Next';
export const labelPrevious = 'Previous';
export const labelApply = 'Apply';
export const labelRequired = 'Required';

==> centreon-web-24.10.17.tar.gz: centreon-web-24.10.17/www/front_src/src/PollerWizard/translatedLabels.ts <==
export const labelExportGenerationTimeout = 'Export generation timeout';
export const labelAdvancedServerConfiguration =
  'Add advanced server configuration';

export const labelCreatePoller = 'Create new Poller';
export const labelSelectPoller = 'Select a Poller';
export const labelSelectPollerIp = 'Select Pending Poller IP';
export const labelCheckCertificate = 'Do not check SSL certificate validation';

export const labelCreatingExportTask = 'Creating Export Task';
export const labelGeneratingExportFiles = 'Generating Export Files';
export const labelAddACentreonPoller = 'Add a Centreon Poller';
export const labelAddACentreonRemoteServer = 'Add a Centreon Remote Server';
export const labelServerConfiguration = 'Server Configuration';
export const labelChoseServerType = 'Choose a server type';
export const labelCreateRemoteServer = 'Create new Remote Server';
export const labelSelectRemoteServer = 'Select a Remote Server';
export const labelSelectRemoteLinks = 'Select Pending Remote Links';
export const labelServerName = 'Server Name';
export const labelServerIp = 'Server address';

export const labelDbUser = 'Database username';
export const labelDbPassword = 'Database password';

export const labelCentreonCentralIp =
  'Centreon Central address, as seen by this server';
export const labelCentreonFolder = 'Centreon Web Folder on Remote';

export const labelLinkedRemoteMaster =
  'Attach poller to a master remote server';

export const labelLinkedadditionalRemote =
  'Attach poller to additional remote servers';

export const labelRemoteServers =
  'Select pollers to be attached to this new Remote Server';

export const labelOpenBrokerFlow =
  'Advanced: reverse Centreon Broker communication flow';

export const labelDoNotUseConfiguredProxy =
  'Do not use configured proxy to connect to this server';

export const labelFinalStep = 'Finalizing Setup';
export const labelNext = 'Next';
export const labelPrevious = 'Previous';
export const labelApply = 'Apply';
export const labelRequired = 'Required';
